==> staros-1.1.tar.gz: staros-1.1/staros/connection.py <==
#!/usr/bin/python
import paramiko, time


def _getsshdata(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=5, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(4)
    output = remote_conn.recv(20000)
    return output


def _getsshdata1(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=5, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(2)
    output = remote_conn.recv(10000)
    return output


def _getsshdata2(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=5, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(1)
    output = remote_conn.recv(5000)
    return output


def _getsshdata3(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=15, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(10)
    output = remote_conn.recv(50000)
    return output

def _getsshdata4(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=15, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(15)
    output = remote_conn.recv(500000)
    return output

def _getsshdata4dnsClearContextGn(host, port, user, passwd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=7, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    remote_conn.send('context Gn\n')
    time.sleep(1)
    cnt = remote_conn.send('clear dns-client dns-1 cache\n')
    time.sleep(1)
    output = remote_conn.recv(10000)
    return output


def _getsshdata5(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=5, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(1)
    output = remote_conn.recv(2000)
    return output

==> staros-1.3.tar.gz: staros-1.3/staros/connection.py <==
#!/usr/bin/python
import paramiko, time
import re


def _getsshdata(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=5, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(4)
    output = remote_conn.recv(20000)
    return output


def _getsshdata1(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=5, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(2)
    output = remote_conn.recv(10000)
    return output


def _getsshdata2(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=5, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(1)
    output = remote_conn.recv(5000)
    return output


def _getsshdata3(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=15, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(10)
    output = remote_conn.recv(50000)
    return output

def _getsshdata4(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=40, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    #output = remote_conn.recv(1500000)
    #print output
    cnt = remote_conn.send('Y\n')
    time.sleep(1)
    remote_conn.send(cmd)
    time.sleep(30)
    output = remote_conn.recv(1500000)
    print (output)
    return output


def _getsshdata4dnsClearContextGn(host, port, user, passwd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=7, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    remote_conn.send('context Gn\n')
    time.sleep(1)
    cnt = remote_conn.send('clear dns-client dns-1 cache\n')
    time.sleep(1)
    output = remote_conn.recv(10000)
    return output


def _getsshdata5(host, port, user, passwd, cmd):
    ssh = paramiko.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.load_system_host_keys()
    ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
    conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=5, look_for_keys=False)
    remote_conn = ssh.invoke_shell()
    cnt = remote_conn.send(cmd)
    time.sleep(1)
    output = remote_conn.recv(2000)
    return output
